==> syslog-ng-devel-2024.09.12_0.darwin_10.ppc.tbz2: opt/local/include/syslog-ng/syslog-ng-config.h <==
#define SYSLOG_NG_JOURNALD_OFF 0
#define SYSLOG_NG_JOURNALD_OPTIONAL 1
#define SYSLOG_NG_JOURNALD_SYSTEM 2
#define SYSLOG_NG_SYSTEMD_JOURNAL_MODE SYSLOG_NG_JOURNALD_OFF
#define SYSLOG_NG_HAVE_JOURNAL_NAMESPACES 0
#define SYSLOG_NG_HAVE_INET_ATON
#define SYSLOG_NG_HAVE_STRTOIMAX 1
#define SYSLOG_NG_HAVE_STRTOLL
#define SYSLOG_NG_HAVE_STRUCT_SOCKADDR_STORAGE 1
#define SYSLOG_NG_MODULE_PATH "${exec_prefix}/lib/syslog-ng"

#define SYSLOG_NG_PATH_DATADIR "${datarootdir}"
#define SYSLOG_NG_PATH_PKGDATADIR "${datarootdir}/syslog-ng"
#define SYSLOG_NG_PATH_DATAROOTDIR "${prefix}/share"
#define SYSLOG_NG_PATH_EXECPREFIX "${prefix}"
#define SYSLOG_NG_PATH_LIBEXECDIR "${exec_prefix}/libexec"
#define SYSLOG_NG_PATH_LOCALSTATEDIR "${prefix}/var"
#define SYSLOG_NG_PATH_MODULEDIR  "${exec_prefix}/lib/syslog-ng"
#define SYSLOG_NG_PATH_PIDFILEDIR "${localstatedir}"
#define SYSLOG_NG_PATH_PREFIX "/opt/local"
#define SYSLOG_NG_PATH_SYSCONFDIR "${prefix}/etc"
#define SYSLOG_NG_PACKAGE_NAME "syslog-ng"
#define SYSLOG_NG_PATH_CONFIG_INCLUDEDIR "${datadir}/syslog-ng/include"
#define SYSLOG_NG_PATH_SCLDIR "${datadir}/syslog-ng/include/scl"
#define SYSLOG_NG_PATH_TOPSRC_DIR "/opt/local/var/macports/build/_opt_PPCSnowLeopardPorts_sysutils_syslog-ng-devel/syslog-ng-devel/work/syslog-ng-e703ed7eaac140716298bf6229b764364b754afc"

#define SYSLOG_NG_SOURCE_REVISION "4.8.0.146.ge703ed7.dirty"
#define SYSLOG_NG_VERSION "4.8.0.146.ge703ed7.dirty"
#define SYSLOG_NG_COMBINED_VERSION "4.8.0.146.ge703ed7.dirty"
#define SYSLOG_NG_ENABLE_CPP 1
#define SYSLOG_NG_ENABLE_FORCED_SERVER_MODE 1
#define SYSLOG_NG_ENABLE_DEBUG 0
#define SYSLOG_NG_ENABLE_GPROF 0
#define SYSLOG_NG_ENABLE_IPV6 1
#define SYSLOG_NG_HAVE_GETADDRINFO 1
#define SYSLOG_NG_HAVE_GETNAMEINFO 1
/* #undef SYSLOG_NG_HAVE_TCP_KEEPALIVE_TIMERS */
#define SYSLOG_NG_HAVE_STRNLEN
#define SYSLOG_NG_HAVE_GETLINE
#define SYSLOG_NG_ENABLE_LINUX_CAPS 0
#define SYSLOG_NG_ENABLE_MEMTRACE 0
#define SYSLOG_NG_ENABLE_TCP_WRAPPER 1
#define SYSLOG_NG_ENABLE_SYSTEMD 0
#define SYSLOG_NG_HAVE_STRUCT_UCRED 1
#define SYSLOG_NG_HAVE_CTRLBUF_IN_MSGHDR 1
#define SYSLOG_NG_ENABLE_SPOOF_SOURCE 1
#define SYSLOG_NG_PATH_XSDDIR "${datadir}/syslog-ng/xsd"
/* #undef SYSLOG_NG_HAVE_GETUTENT */
#define SYSLOG_NG_HAVE_GETUTXENT 1
#define SYSLOG_NG_HAVE_DLFCN_H 1
#define SYSLOG_NG_HAVE_UTMPX_H 1
#define SYSLOG_NG_HAVE_UTMP_H 1
#define SYSLOG_NG_HAVE_MODERN_UTMP 1
#define SYSLOG_NG_JAVA_MODULE_PATH "${exec_prefix}/lib/syslog-ng/java-modules"
#define SYSLOG_NG_PYTHON_MODULE_DIR "${exec_prefix}/lib/syslog-ng/python"
#define SYSLOG_NG_PYTHON_SYSCONF_MODULE_DIR "${exec_prefix}/lib/syslog-ng/python"
#define SYSLOG_NG_PYTHON_VENV_DIR "${localstatedir}/python-venv"
#define SYSLOG_NG_HAVE_CLOCK_GETTIME 1
#define SYSLOG_NG_HAVE_STRTOK_R
/* #undef ENV_LD_LIBRARY_PATH */
#define SYSLOG_NG_HAVE_DECL_EVP_MD_CTX_RESET 1
#define SYSLOG_NG_HAVE_DECL_ASN1_STRING_GET0_DATA 1
#define SYSLOG_NG_HAVE_DECL_SSL_CONF_CTX_NEW 1
#define SYSLOG_NG_HAVE_DECL_SSL_CTX_GET0_PARAM 1
#define SYSLOG_NG_HAVE_DECL_SSL_CTX_SET_CIPHERSUITES 1
#define SYSLOG_NG_HAVE_DECL_SSL_CTX_SET1_SIGALGS_LIST 1
#define SYSLOG_NG_HAVE_DECL_SSL_CTX_SET1_CLIENT_SIGALGS_LIST 1
#define SYSLOG_NG_HAVE_DECL_SSL_CTX_SET_MIN_PROTO_VERSION 1
#define SYSLOG_NG_HAVE_DECL_X509_STORE_CTX_GET0_CERT 1
#define SYSLOG_NG_HAVE_DECL_X509_GET_EXTENSION_FLAGS 1
#define SYSLOG_NG_HAVE_DECL_DH_SET0_PQG 1
#define SYSLOG_NG_HAVE_DECL_BN_GET_RFC3526_PRIME_2048 1
#define SYSLOG_NG_HAVE_DECL_SSL_CTX_SET_NUM_TICKETS 1
#define SYSLOG_NG_HAVE_DECL_SSL_ADD_DIR_CERT_SUBJECTS_TO_STACK 1
#define SYSLOG_NG_HAVE_DECL_SSL_ADD_FILE_CERT_SUBJECTS_TO_STACK 1
#define SYSLOG_NG_HAVE_DECL_MONGOC_URI_SET_OPTION_AS_INT32 0
#define SYSLOG_NG_HAVE_DECL_MONGOC_URI_SERVERSELECTIONTIMEOUTMS 0
#define SYSLOG_NG_HAVE_INOTIFY 0
#define SYSLOG_NG_HAVE_KQUEUE 1
/* #undef SYSLOG_NG_HAVE_GETRANDOM */
#define SYSLOG_NG_USE_CONST_IVYKIS_MOCK 1
#define SYSLOG_NG_HAVE_ENVIRON 0
#define SYSLOG_NG_HAVE_FMEMOPEN 1
#define SYSLOG_NG_ENABLE_ENV_WRAPPER 0
#define SYSLOG_NG_HAVE_GETOPT_H 1
/* #undef SYSLOG_NG_HAVE_GETPROTOBYNUMBER_R */
#define SYSLOG_NG_HAVE_G_LIST_COPY_DEEP
#define SYSLOG_NG_HAVE_G_PTR_ARRAY_FIND_WITH_EQUAL_FUNC
#define SYSLOG_NG_HAVE_G_CANONICALIZE_FILENAME
#define SYSLOG_NG_HAVE_GMTIME_R
#define SYSLOG_NG_HAVE_LOCALTIME_R
/* #undef SYSLOG_NG_HAVE_AMQP_SSL_SOCKET_SET_VERIFY_PEER */
/* #undef SYSLOG_NG_HAVE_RABBITMQ_C_TCP_SOCKET_H */
#define SYSLOG_NG_HAVE_INET_NTOA 1
/* #undef SYSLOG_NG_HAVE_MEMRCHR */
/* #undef SYSLOG_NG_HAVE_O_LARGEFILE */
#define SYSLOG_NG_HAVE_PREAD
#define SYSLOG_NG_HAVE_PWRITE 1
/* #undef SYSLOG_NG_HAVE_POSIX_FALLOCATE */
#define SYSLOG_NG_HAVE_STRCASESTR
#define SYSLOG_NG_HAVE_STRUCT_TM_TM_GMTOFF 1
#define SYSLOG_NG_HAVE_THREAD_KEYWORD 1
#define SYSLOG_NG_HAVE_TIMEZONE 1
#define SYSLOG_NG_WITH_COMPILE_DATE 0
/* #undef SYSLOG_NG_HAVE_RD_KAFKA_INIT_TRANSACTIONS */
#define SYSLOG_NG_HAVE_PAHO_HTTP_PROXY 0
/* #undef SYSLOG_NG_HAVE_LINUX_SOCK_DIAG_H */
#define SYSLOG_NG_HAVE_SO_MEMINFO 0
#define SYSLOG_NG_ENABLE_AFSOCKET_MEMINFO_METRICS 0
#define SYSLOG_NG_HAVE_IV_WORK_POOL_SUBMIT_CONTINUATION 0

==> syslog-ng-devel-2025.06.12_0.darwin_10.ppc.tbz2: opt/local/include/syslog-ng/syslog-ng-config.h <==
#define SYSLOG_NG_JOURNALD_OFF 0
#define SYSLOG_NG_JOURNALD_OPTIONAL 1
#define SYSLOG_NG_JOURNALD_SYSTEM 2
#define SYSLOG_NG_SYSTEMD_JOURNAL_MODE SYSLOG_NG_JOURNALD_OFF
#define SYSLOG_NG_HAVE_JOURNAL_NAMESPACES 0
#define SYSLOG_NG_HAVE_INET_ATON
#define SYSLOG_NG_HAVE_STRTOIMAX 1
#define SYSLOG_NG_HAVE_STRTOLL
#define SYSLOG_NG_HAVE_STRUCT_SOCKADDR_STORAGE 1
#define SYSLOG_NG_MODULE_PATH "${exec_prefix}/lib/syslog-ng"

#define SYSLOG_NG_PATH_DATADIR "${datarootdir}"
#define SYSLOG_NG_PATH_PKGDATADIR "${datarootdir}/syslog-ng"
#define SYSLOG_NG_PATH_DATAROOTDIR "${prefix}/share"
#define SYSLOG_NG_PATH_EXECPREFIX "${prefix}"
#define SYSLOG_NG_PATH_LIBEXECDIR "${exec_prefix}/libexec"
#define SYSLOG_NG_PATH_LOCALSTATEDIR "${prefix}/var"
#define SYSLOG_NG_PATH_MODULEDIR  "${exec_prefix}/lib/syslog-ng"
#define SYSLOG_NG_PATH_PIDFILEDIR "${localstatedir}"
#define SYSLOG_NG_PATH_PREFIX "/opt/local"
#define SYSLOG_NG_PATH_SYSCONFDIR "${prefix}/etc"
#define SYSLOG_NG_PACKAGE_NAME "syslog-ng"
#define SYSLOG_NG_PATH_CONFIG_INCLUDEDIR "${datadir}/syslog-ng/include"
#define SYSLOG_NG_PATH_SCLDIR "${datadir}/syslog-ng/include/scl"
#define SYSLOG_NG_PATH_TOPSRC_DIR "/opt/local/var/macports/build/_opt_local_ppcports_sysutils_syslog-ng-devel/syslog-ng-devel/work/syslog-ng-c643e840a9ae1d69671720c0a2d3b862c26c5ebb"

#define SYSLOG_NG_SOURCE_REVISION "4.8.3.613.gc643e84"
#define SYSLOG_NG_VERSION "4.8.3.613.gc643e84"
#define SYSLOG_NG_COMBINED_VERSION "4.8.3.613.gc643e84"

#define SYSLOG_NG_ENABLE_AFSOCKET_MEMINFO_METRICS 0
#define SYSLOG_NG_ENABLE_CPP 1
#define SYSLOG_NG_ENABLE_DEBUG 0
#define SYSLOG_NG_ENABLE_ENV_WRAPPER 0
#define SYSLOG_NG_ENABLE_FORCED_SERVER_MODE 1
#define SYSLOG_NG_ENABLE_GCOV 0
#define SYSLOG_NG_ENABLE_GPROF 0
#define SYSLOG_NG_ENABLE_IPV6 1
#define SYSLOG_NG_ENABLE_LINUX_CAPS 0
#define SYSLOG_NG_ENABLE_MEMTRACE 0
#define SYSLOG_NG_ENABLE_PERF 0
#define SYSLOG_NG_ENABLE_SPOOF_SOURCE 1
#define SYSLOG_NG_ENABLE_STACKDUMP 0
#define SYSLOG_NG_ENABLE_SYSTEMD 0
#define SYSLOG_NG_ENABLE_TCP_WRAPPER 1

#define SYSLOG_NG_HAVE_GETADDRINFO 1
#define SYSLOG_NG_HAVE_GETNAMEINFO 1
/* #undef SYSLOG_NG_HAVE_TCP_KEEPALIVE_TIMERS */
#define SYSLOG_NG_HAVE_STRNLEN
#define SYSLOG_NG_HAVE_GETLINE
#define SYSLOG_NG_HAVE_STRUCT_UCRED 1
#define SYSLOG_NG_HAVE_STRUCT_CMSGCRED 0
#define SYSLOG_NG_HAVE_CTRLBUF_IN_MSGHDR 1
#define SYSLOG_NG_PATH_XSDDIR "${datadir}/syslog-ng/xsd"
/* #undef SYSLOG_NG_HAVE_GETUTENT */
#define SYSLOG_NG_HAVE_GETUTXENT 1
#define SYSLOG_NG_HAVE_DLFCN_H 1
#define SYSLOG_NG_HAVE_UTMPX_H 1
#define SYSLOG_NG_HAVE_UTMP_H 1
#define SYSLOG_NG_HAVE_MODERN_UTMP 1
#define SYSLOG_NG_JAVA_MODULE_PATH "${exec_prefix}/lib/syslog-ng/java-modules"
#define SYSLOG_NG_PYTHON_MODULE_DIR "${exec_prefix}/lib/syslog-ng/python"
#define SYSLOG_NG_PYTHON_SYSCONF_MODULE_DIR "${exec_prefix}/lib/syslog-ng/python"
#define SYSLOG_NG_PYTHON_VENV_DIR "${localstatedir}/python-venv"
#define SYSLOG_NG_HAVE_CLOCK_GETTIME 1
#define SYSLOG_NG_HAVE_STRTOK_R
/* #undef ENV_LD_LIBRARY_PATH */
#define SYSLOG_NG_HAVE_DECL_EVP_MD_CTX_RESET 1
#define SYSLOG_NG_HAVE_DECL_ASN1_STRING_GET0_DATA 1
#define SYSLOG_NG_HAVE_DECL_SSL_CONF_CTX_NEW 1
#define SYSLOG_NG_HAVE_DECL_SSL_CTX_GET0_PARAM 1
#define SYSLOG_NG_HAVE_DECL_SSL_CTX_SET_CIPHERSUITES 1
#define SYSLOG_NG_HAVE_DECL_SSL_CTX_SET1_SIGALGS_LIST 1
#define SYSLOG_NG_HAVE_DECL_SSL_CTX_SET1_CLIENT_SIGALGS_LIST 1
#define SYSLOG_NG_HAVE_DECL_SSL_CTX_SET_MIN_PROTO_VERSION 1
#define SYSLOG_NG_HAVE_DECL_X509_STORE_CTX_GET0_CERT 1
#define SYSLOG_NG_HAVE_DECL_X509_GET_EXTENSION_FLAGS 1
#define SYSLOG_NG_HAVE_DECL_DH_SET0_PQG 1
#define SYSLOG_NG_HAVE_DECL_BN_GET_RFC3526_PRIME_2048 1
#define SYSLOG_NG_HAVE_DECL_SSL_CTX_SET_NUM_TICKETS 1
#define SYSLOG_NG_HAVE_DECL_SSL_ADD_DIR_CERT_SUBJECTS_TO_STACK 1
#define SYSLOG_NG_HAVE_DECL_SSL_ADD_FILE_CERT_SUBJECTS_TO_STACK 1
#define SYSLOG_NG_HAVE_DECL_MONGOC_URI_SET_OPTION_AS_INT32 0
#define SYSLOG_NG_HAVE_DECL_MONGOC_URI_SERVERSELECTIONTIMEOUTMS 0
#define SYSLOG_NG_HAVE_INOTIFY 0
#define SYSLOG_NG_HAVE_KQUEUE 1
/* #undef SYSLOG_NG_HAVE_GETRANDOM */
#define SYSLOG_NG_USE_CONST_IVYKIS_MOCK 1
#define SYSLOG_NG_HAVE_ENVIRON 0
#define SYSLOG_NG_HAVE_FMEMOPEN 1
#define SYSLOG_NG_HAVE_GETOPT_H 1
/* #undef SYSLOG_NG_HAVE_GETPROTOBYNUMBER_R */
#define SYSLOG_NG_HAVE_G_LIST_COPY_DEEP
#define SYSLOG_NG_HAVE_G_PTR_ARRAY_FIND_WITH_EQUAL_FUNC
#define SYSLOG_NG_HAVE_G_CANONICALIZE_FILENAME
#define SYSLOG_NG_HAVE_GMTIME_R
#define SYSLOG_NG_HAVE_LOCALTIME_R
#define SYSLOG_NG_HAVE_AMQP_SSL_SOCKET_SET_VERIFY_PEER
#define SYSLOG_NG_HAVE_RABBITMQ_C_TCP_SOCKET_H
#define SYSLOG_NG_HAVE_INET_NTOA 1
/* #undef SYSLOG_NG_HAVE_MEMRCHR */
/* #undef SYSLOG_NG_HAVE_O_LARGEFILE */
#define SYSLOG_NG_HAVE_PREAD
#define SYSLOG_NG_HAVE_PWRITE 1
/* #undef SYSLOG_NG_HAVE_POSIX_FALLOCATE */
#define SYSLOG_NG_HAVE_STRCASESTR
#define SYSLOG_NG_HAVE_STRUCT_TM_TM_GMTOFF 1
#define SYSLOG_NG_HAVE_THREAD_KEYWORD 1
#define SYSLOG_NG_HAVE_TIMEZONE 1
#define SYSLOG_NG_WITH_COMPILE_DATE 0
/* #undef SYSLOG_NG_HAVE_RD_KAFKA_INIT_TRANSACTIONS */
#define SYSLOG_NG_HAVE_PAHO_HTTP_PROXY 1
/* #undef SYSLOG_NG_HAVE_LINUX_SOCK_DIAG_H */
#define SYSLOG_NG_HAVE_SO_MEMINFO 0
#define SYSLOG_NG_HAVE_IV_WORK_POOL_SUBMIT_CONTINUATION 0
#define SYSLOG_NG_HAVE_DECL_CURLUE_LAST 1
